# PolicyConfigAuthzBundle

A PolicyConfigAuthzBundle bundle contains various components for an organisation that drives various authentication and authorization rules as well as necessary backend data sources. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**digest** | **str** | a sha256 digest of backend_data. | [optional] 
**backend_data** | [**AuthzBundle**](AuthzBundle.md) |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


